@@ -1,6 +1,6 @@
-"""Steroids is a set of tools to help python developers to build real-time ready, non-blocking, web application reducing efforts and time."""
+"""Steroids is a set of tools to help python developers to build cool stuff reducing efforts and time."""
 
-__version__ = "0.11.2"
+__version__ = "0.11.3"
 __author__ = "Lorenzo Setale ( http://who.is.lorenzo.setale.me/? )"
 __author_email__ = "koalalorenzo@gmail.com"
 __license__ = "Creative Commons Attribution-ShareAlike 3.0 Unported License http://creativecommons.org/licenses/by-nd/3.0/ "
